@@ -2,17 +2,18 @@ from pgkit.application.utils import execute_sync
 
 
 class Postgres:
-    def __init__(self, name, host, port, version, username, password, slot):
+    def __init__(self, name, host, port, version, dbname, username, password, slot):
         self.name = name
         self.host = host
         self.port = port
         self.version = version
+        self.dbname = dbname
         self.username = username
         self.password = password
         self.slot = slot
 
     def run_cmd(self, cmd):
-        execute_sync(f'psql -h {self.host} -p {self.port} -U {self.username} -c {cmd}',
+        execute_sync(f'psql -h {self.host} -p {self.port} -U {self.username} -d {self.dbname} -c {cmd}',
                      env=[('PGPASSWORD', self.password)])
 
     def force_switch_wal(self):
